@@ -99,6 +99,7 @@ class LupusecAPI:
         self._cacheBinarySensors = None
         self._cacheSensors = None
         self._cacheSwitches = None
+        self._cacheCovers = None
         self._devices = None
         self._apiDevices = None
 
@@ -293,17 +294,17 @@ class LupusecAPI:
         _LOGGER.debug("__init__.py.async_set_mode() finished.")
 
 
-    async def async_set_switch(self, switch, mode) -> None:
-        """Async method to set switches."""
+    async def async_set_switch(self, zone, mode) -> None:
+        """ Async method to set switches. """
+        """ zone corresponds to the Lupusec Zone Number """
+        """ Expects: mode = "on" (set to OFF) or mode = "off" (set to ON) """
         _LOGGER.debug("__init__.py.async_set_switch() called: ")
-        _LOGGER.info("...for switch: %s, set mode: %s", switch, mode)
-        execution = "a=1&z=" + str(switch) + "&sw=" + mode + "&pd="
+        _LOGGER.info("...for switch (zone): %s, set mode: %s", zone, mode)
+        execution = "a=1&z=" + str(zone) + "&sw=" + mode + "&pd="
         # example: exec: a=1&z=20&sw=on&pd=
         _LOGGER.debug("{ exec: %s}", execution)        
         params = {"exec": execution}
-        print(params)
-
-         # Control Switch
+        # Control Switch
         async with aiohttp.ClientSession(auth=self._auth) as session:
             _LOGGER.debug("auth.encode: %s", self._auth.encode())            
 
@@ -325,10 +326,10 @@ class LupusecAPI:
 
                 if (sys.getsizeof(set_switch_response) > 0):
                     _LOGGER.debug("RESULT_RESPONSE: %s", set_switch_response[CONST.RESPONSE_RESULT]) 
-                    if (token_response[CONST.RESPONSE_RESULT] == 1):
+                    if (set_switch_response[CONST.RESPONSE_RESULT] == 1):
                         _LOGGER.debug("RESPONSE_MESSAGE: %s", set_switch_response[CONST.RESPONSE_MESSAGE]) 
                         if (len(set_switch_response[CONST.RESPONSE_MESSAGE]) != 0):
-                            _LOGGER.info("...switch: %s, set to mode: %s", switch, mode)
+                            _LOGGER.info("...switch (zone): %s, set to mode: %s", zone, mode)
                     else :
                         _LOGGER.info("ERROR: RESULT_RESPONSE: %s", set_switch_response[CONST.RESPONSE_RESULT])
                         _LOGGER.info("RESPONSE_MESSAGE: %s", set_switch_response[CONST.RESPONSE_MESSAGE])  
@@ -338,9 +339,9 @@ class LupusecAPI:
         _LOGGER.debug("__init__.py.async_set_switch() finished.")
 
 
-    async def get_switches(self) -> Dict:
+    async def get_switches_async(self) -> Dict:
         """Async method to get switches."""
-        _LOGGER.debug("__init__.py.get_switches() called: ")
+        _LOGGER.debug("__init__.py.get_switches_async() called: ")
         timeNow = time.time()
         
         # Get switches from cache or update from Lupusec System
@@ -372,11 +373,11 @@ class LupusecAPI:
                                 _LOGGER.debug("device is no switch...skipping.")
                         self._cacheSwitches = switches
                     else : 
-                        _LOGGER.info("ERROR: get_switches(): no switches found.")
+                        _LOGGER.info("ERROR: get_switches_async(): no switches found.")
                 else :
-                    _LOGGER.info("ERROR: get_switches(): no switches found.")
+                    _LOGGER.info("ERROR: get_switches_async(): no switches found.")
 
-        _LOGGER.debug("__init__.py.get_switches() finished.") 
+        _LOGGER.debug("__init__.py.get_switches_async() finished.") 
 
         if (len(self._cacheSwitches) != 0):
             print("Number of switches=", len(self._cacheSwitches))            
@@ -389,6 +390,53 @@ class LupusecAPI:
                     ", status: ", switch["status_ex"])
         return self._cacheSwitches
 
+
+    async def get_covers_async(self) -> Dict:
+        """Async method to get covers."""
+        _LOGGER.debug("__init__.py.get_covers_async called: ")
+        timeNow = time.time()
+        
+        # Get covers from cache or update from Lupusec System
+        # ToDo: update frequency shall not be hard-coded -> transfer to constant
+        if self._cacheCovers is None or timeNow - self._cacheStampP > 2.0:
+            _LOGGER.debug("...covers need update from Lupusec System.")
+            self._cacheStamp_p = timeNow
+
+            async with aiohttp.ClientSession(auth=self._auth) as session:
+                _LOGGER.debug("auth.encode: %s", self._auth.encode())  
+
+                # Get all devices and filter for covers
+                _LOGGER.debug("__init__.py.get_covers_async(): REQUEST=%s", CONST.DEVICE_LIST_REQUEST)
+                get_covers_response = await LupusecAPI._async_api_call(self._ip_address, session, CONST.DEVICE_LIST_REQUEST)
+                _LOGGER.debug("_async_api_call(): done. check response...")
+                # Retreive Device Liste from Response
+                if CONST.DEVICE_LIST_HEADER in get_covers_response:
+                    device_content = get_covers_response[CONST.DEVICE_LIST_HEADER]
+                    print("Number of devices=", len(device_content))    
+                    if (len(device_content) != 0):             
+                        covers = []
+                        for device in device_content:
+                            _LOGGER.debug("Device found: sid=%s, name=%s, type=%s, status=%s", 
+                                device["sid"], device["name"], device["type"], device["status_ex"] )
+                            if (device["type"] in CONST.TYPES_COVER):    
+                                covers.append(device)
+                                _LOGGER.debug("device is shutter...added.")
+                            else :
+                                _LOGGER.debug("device is no shutter...skipping.")
+                        self._cacheCovers = covers
+                    else : 
+                        _LOGGER.info("ERROR: get_covers_async(): no covers found.")
+                else :
+                    _LOGGER.info("ERROR: get_covers_async(): no covers found.")
+
+        _LOGGER.debug("__init__.py.get_covers_async() finished.") 
+
+        if (len(self._cacheCovers) != 0):
+            _LOGGER.debug("Number of covers=%s", len(self._cacheCovers)) 
+
+        return self._cacheCovers
+
+
     async def get_binary_sensors(self) -> Dict:
         """Async method to get BinarySensors."""
         _LOGGER.debug("__init__.py.get_binary_sensors() called: ")
@@ -549,19 +597,68 @@ class LupusecAPI:
                     _LOGGER.info("ERROR: get_switch_async(): no Switch found.")
             _LOGGER.debug("__init__.py.get_switch_async(): update from LupusecAPI finished.") 
 
+
+
+    async def get_cover_async(self, device_id) -> Dict:
+        """Async method to get a single cover device."""
+        _LOGGER.debug("__init__.py.get_cover_async() called for device_id=%s", device_id)
+        timeNow = time.time()
+        
+        # Get device from cache or update from Lupusec System
+        # ToDo: update frequency shall not be hard-coded -> transfer to constant
+        if self._cacheCovers is None or timeNow - self._cacheStampP > 10.0:
+            # time elapsed, devices need update from Lupusec System.
+            if self._cacheCovers is None:
+                _LOGGER.debug("__init__.py.get_covers_async(): cacheCovers is none, update from Lupusec System started.")
+            if timeNow - self._cacheStampP > 2.0:
+                _LOGGER.debug("__init__.py.get_covers_async(): time elapsed, update from Lupusec System started.")    
+            self._cacheStampP = timeNow
+
+            async with aiohttp.ClientSession(auth=self._auth) as session:
+                _LOGGER.debug("auth.encode: %s", self._auth.encode())  
+
+                # Get all devices from LupusecAPI
+                _LOGGER.debug("__init__.py.get_cover_async(): REQUEST=%s", CONST.DEVICE_LIST_REQUEST)
+                get_bin_covers_response = await LupusecAPI._async_api_call(self._ip_address, session, CONST.DEVICE_LIST_REQUEST)
+                _LOGGER.debug("_async_api_call(): done. check response...")
+                # Retreive Device Liste from Response
+                if CONST.DEVICE_LIST_HEADER in get_bin_covers_response:
+                    device_content = get_bin_covers_response[CONST.DEVICE_LIST_HEADER]
+                    _LOGGER.debug("Number of devices found: %s", len(device_content))    
+                    if (len(device_content) != 0):             
+                        covers = []
+                        for device in device_content:
+                            if (device["type"] in CONST.TYPES_COVER):    
+                                covers.append(device)
+                                _LOGGER.debug("Cover found: sid=%s, name=%s, type=%s, status=%s", 
+                                    device["sid"], device["name"], device["type"], device["status_ex"] )
+                                _LOGGER.debug("sid=%s, python_class=%s", 
+                                    device["sid"], type(device["sid"]))                                    
+                            else :
+                                _LOGGER.debug("device is no Cover...skipping.")
+                        self._cacheCovers = covers
+                        _LOGGER.debug("get_cover_async(): No of updated Covers: %s", len(self._cacheCovers))
+                    else : 
+                        _LOGGER.info("ERROR: get_cover_async(): no Cover found.")
+                else :
+                    _LOGGER.info("ERROR: get_cover_async(): no Cover found.")
+            _LOGGER.debug("__init__.py.get_cover_async(): update from LupusecAPI finished.") 
+
+
+
         # time not elapsed, Devices do not need update from Lupusec System...using Cache
-        _LOGGER.debug("__init__.py.get_switch_async(): using Cache to provide Update on Switch.")
-        if (len(self._cacheSwitches) != 0):  
-            _LOGGER.debug("__init__.py.get_switch_async(): Number of Switches=%s", len(self._cacheSwitches))             
-            for switch in self._cacheSwitches:
-                #_LOGGER.debug("__init__.py.get_switch_async(): device with sid=%s, name=%s", sensor["sid"], sensor["name"])
-                if (switch["sid"] == device_id):
-                    _LOGGER.debug("__init__.py.get_switch_async(): matching device with sid=%s found: status=%s", switch["sid"], switch["status_ex"])
-                    return switch    
-            _LOGGER.error("__init__.py.get_switch_async(): %s Switches checked, but no device found with sid=%s", len(self._cacheSwitches), device_id)
+        _LOGGER.debug("__init__.py.get_cover_async(): using Cache to provide Update on Switch.")
+        if (len(self._cacheCovers) != 0):  
+            _LOGGER.debug("__init__.py.get_cover_async(): Number of Covers=%s", len(self._cacheCovers))             
+            for cover in self._cacheCovers:
+                #_LOGGER.debug("__init__.py.get_cover_async(): device with sid=%s, name=%s", sensor["sid"], sensor["name"])
+                if (cover["sid"] == device_id):
+                    _LOGGER.debug("__init__.py.get_cover_async(): matching device with sid=%s found: status=%s", cover["sid"], cover["status_ex"])
+                    return cover    
+            _LOGGER.error("__init__.py.get_cover_async(): %s Covers checked, but no device found with sid=%s", len(self._cacheCovers), device_id)
             return {}
         else :
-            _LOGGER.debug("ERROR: length of self._cacheSwitches = 0") 
+            _LOGGER.debug("ERROR: length of self._cacheCovers = 0") 
             return {}
 
 
