@@ -4,7 +4,7 @@
 # -*- coding: utf-8 -*-
 
 # Project Information
-VERSION = "0.3.77"
+VERSION = "0.3.83"
 PROJECT_PACKAGE_NAME = "lupulib"
 PROJECT_LICENSE = "MIT"
 PROJECT_URL = "http://www.github.com/majuss/lupulib"
@@ -33,7 +33,8 @@ INFO_HEADER = "updates"
 TOKEN_REQUEST = "tokenGet"
 SET_ALARM_REQUEST = "panelCondPost"
 EXECUTE_REQUEST = "haExecutePost"
-DEVICE_LIST_REQUEST = "deviceListGet"
+# DEVICE_LIST_REQUEST = "deviceListGet"
+DEVICE_LIST_REQUEST = "deviceGet"
 DEVICE_LIST_HEADER = "senrows"
 HISTORY_REQUEST = "historyGet"
 HISTORY_ALARM_COLUMN = "a"
@@ -72,7 +73,7 @@ TYPE_WATER_XT2 = 5
 TYPE_SMOKE_XT2 = 11
 TYPE_SWITCH_INT_XT2 = 48
 TYPE_SWITCH_EXT_XT2 = 81
-TYPE_UPDOWN_SWITCH_XT2 = 76
+TYPE_COVER_XT2 = 76
 TYPE_THERMAL_SWITCH_XT2 = 79
 TYPE_LIGHT_XT2 = 74
 
@@ -80,7 +81,7 @@ TYPE_LIGHT_XT2 = 74
 TYPES_BIN_SENSOR = [TYPE_BIN_SENSOR_XT2]
 TYPES_SENSOR = [TYPE_WATER_XT2, TYPE_SMOKE_XT2]
 TYPES_SWITCH = [TYPE_SWITCH_INT_XT2, TYPE_SWITCH_EXT_XT2]
-TYPES_UPDOWN_SWITCH = [TYPE_UPDOWN_SWITCH_XT2]
+TYPES_COVER = [TYPE_COVER_XT2]
 TYPES_THERMAL_SWITCH = [TYPE_THERMAL_SWITCH_XT2]
 
 
